# EventumStudio
Content designer for Eventum 

## Installation

Using PipX (recommended):
```bash
pipx install eventum-studio
```

Using Pip:
```bash
pip install eventum-studio
```

See more about Eventum Studio here: https://eventum-generatives.github.io/Website/docs/content_designing/eventum_studio/
